@@ -29,7 +29,7 @@ class GoogleSearchConsole:
 
         # Google API Resourse Object created from
         # Connection class in .connect module
-        self.auth = Connection().gsc()
+        self.auth = self.__auth()
 
         # default values for dimensions and date values
         # start date is 7 days ago
@@ -52,6 +52,10 @@ class GoogleSearchConsole:
         # assigned in .ctr()
         self.my_ctr: Optional[pd.DataFrame] = None
 
+    def __auth(self):
+        """Authenticates to Google"""
+        return Connection().gsc()
+
     def __str__(self) -> str:
         if len(self._site_list) > 1:
             return f"Custom GSC Wrapper for {len(self._site_list)} sites"
